@@ -25,3 +25,10 @@ ARG_NAMING_PREFIXES = LONG_ARG_KEY_PREFIXES + ABBREVIATED_ARG_KEY_PREFIXES
 ARG_VALUE_SEPARATOR_CHAR = "="
 
 QUOTE_CHARS = ['"', '\'']
+
+KEY_NAMES = "names"
+KEY_DESCRIPTION = "description"
+KEY_ARGUMENTS = "arguments"
+KEY_HELP_MESSAGE = "help_message"
+KEY_PERMISSIONS = "permissions"
+KEY_HIDDEN = "hidden"
