@@ -24,13 +24,13 @@ from functools import reduce
 from typing import Dict
 
 from telegram import Update
-from telegram.ext import CallbackContext
+from telegram.ext import ContextTypes
 
 
 class Permission:
 
-    def __call__(self, update: Update, context: CallbackContext) -> bool:
-        return self.evaluate(update, context)
+    async def __call__(self, update: Update, context: ContextTypes.DEFAULT_TYPE) -> bool:
+        return await self.evaluate(update, context)
 
     def __and__(self, other):
         return self._merge(other, operator.and_)
@@ -51,7 +51,7 @@ class Permission:
         return "<{}>".format(self.__class__.__name__)
 
     @abstractmethod
-    def evaluate(self, update: Update, context: CallbackContext) -> bool:
+    async def evaluate(self, update: Update, context: ContextTypes.DEFAULT_TYPE) -> bool:
         """
         Evaluates if the permission should be granted
         :param update: the message update
@@ -72,8 +72,8 @@ class InvertedPermission(Permission):
         """
         self.original_permission = original_permission
 
-    def evaluate(self, update: Update, context: CallbackContext) -> bool:
-        return not bool(self.original_permission(update, context))
+    async def evaluate(self, update: Update, context: ContextTypes.DEFAULT_TYPE) -> bool:
+        return not bool(await self.original_permission(update, context))
 
     def __str__(self):
         return "(not {})".format(self.original_permission.__str__())
@@ -99,12 +99,12 @@ class MergedPermission(Permission):
         if self.op not in [operator.and_, operator.or_]:
             raise ValueError("Only operator.and_, operator.or_ are supported")
 
-    def evaluate(self, update: Update, context: CallbackContext) -> bool:
+    async def evaluate(self, update: Update, context: ContextTypes.DEFAULT_TYPE) -> bool:
         """
         Evaluates all given permissions and combines their result using the given operator
         :return: reduced evaluation result
         """
-        evaluations = list(map(lambda x: x.evaluate(update, context), self.permissions))
+        evaluations = [await x.evaluate(update, context) for x in self.permissions]
         return reduce(lambda x, y: self.op(x, y), evaluations)
 
     def __str__(self):
@@ -118,19 +118,19 @@ class MergedPermission(Permission):
         return "<{}>".format(repr)
 
 
-def get_evaluation_tree(update: Update, context: CallbackContext, permission: Permission) -> any:
-    def add_child(tree_node: Dict, permission: Permission):
-        evaluation = permission.evaluate(update, context)
+async def get_evaluation_tree(update: Update, context: ContextTypes.DEFAULT_TYPE, permission: Permission) -> any:
+    async def add_child(tree_node: Dict, permission: Permission):
+        evaluation = await permission.evaluate(update, context)
         tree_node["permission"] = permission
         tree_node["evaluation"] = evaluation
 
         if isinstance(permission, MergedPermission):
             tree_node["op"] = permission.op
             tree_node["left"] = {}
-            add_child(tree_node["left"], permission.permissions[0])
+            await add_child(tree_node["left"], permission.permissions[0])
             tree_node["right"] = {}
-            add_child(tree_node["right"], permission.permissions[1])
+            await add_child(tree_node["right"], permission.permissions[1])
 
     root = {}
-    add_child(root, permission)
+    await add_child(root, permission)
     return root
