@@ -73,7 +73,7 @@ def escape_for_markdown(text: str or None) -> str:
     return escaped
 
 
-def send_message(bot: Bot, chat_id: str, message: str, parse_mode: str = None, reply_to: int = None):
+async def send_message(bot: Bot, chat_id: str, message: str, parse_mode: str = None, reply_to: int = None):
     """
     Sends a text message to the given chat
     :param bot: the bot
@@ -84,5 +84,5 @@ def send_message(bot: Bot, chat_id: str, message: str, parse_mode: str = None, r
     """
     from emoji import emojize
 
-    emojized_text = emojize(message, use_aliases=True)
-    bot.send_message(chat_id=chat_id, parse_mode=parse_mode, text=emojized_text, reply_to_message_id=reply_to)
+    emojized_text = emojize(message)
+    await bot.send_message(chat_id=chat_id, parse_mode=parse_mode, text=emojized_text, reply_to_message_id=reply_to)
